import { IDictionary, Stalk, IPomelo } from "./serverImplemented";
import { HttpStatusCode } from '../utils/httpStatusCode';

export namespace API {
    export class LobbyAPI {
        server: Stalk.ServerImplemented;
        socket: IPomelo;
        constructor(_server: Stalk.ServerImplemented) {
            this.server = _server;
            this.socket = _server.getSocket();
        }

        public checkIn(msg: IDictionary) {
            let self = this;

            return new Promise((resolve, rejected) => {
                // <!-- Authentication.
                self.socket.request("connector.entryHandler.login", msg, function (res) {
                    if (res.code === HttpStatusCode.fail) {
                        rejected(res.message);
                    }
                    else if (res.code === HttpStatusCode.success) {
                        resolve(res);
                    }
                    else {
                        resolve(res);
                    }
                });
            });
        }

        public logout() {
            let registrationId = "";
            let msg = {} as IDictionary;
            msg["username"] = null;
            msg["registrationId"] = registrationId;
            if (this.socket != null) {
                this.socket.notify("connector.entryHandler.logout", msg);
            }

            this.server.disConnect();
            this.server = null;
        }

        // <!-- Join and leave chat room.
        public joinRoom(token: string, username, room_id: string, callback: (err, res) => void) {
            let self = this;
            let msg = {} as IDictionary;
            msg["token"] = token;
            msg["rid"] = room_id;
            msg["username"] = username;
            self.socket.request("connector.entryHandler.enterRoom", msg, (result) => {
                if (callback !== null) {
                    callback(null, result);
                }
            });
        }
        public leaveRoom(token: string, roomId: string, callback: (err, res) => void) {
            let self = this;
            let msg = {} as IDictionary;
            msg["token"] = token;
            msg["rid"] = roomId;
            self.socket.request("connector.entryHandler.leaveRoom", msg, (result) => {
                if (callback != null)
                    callback(null, result);
            });
        }
    }
}